/*
 * tsig.h -- defines for TSIG [RFC2845]
 *
 * Copyright (c) 2001-2005, NLnet Labs. All rights reserved.
 *
 * See LICENSE for the license.
 */

#ifndef _LDNS_TSIG_H_
#define _LDNS_TSIG_H_

#include <ldns/common.h>
#include <ldns/dns.h>
#include <ldns/packet.h>
#include <ldns/zone.h>

typedef struct _ldns_tsig_credentials 
{
    char *algorithm;
    char *keyname;
    char *keydata;
    /* XXX More eventually. */
} ldns_tsig_credentials;

char *ldns_tsig_algorithm(ldns_tsig_credentials *);
char *ldns_tsig_keyname(ldns_tsig_credentials *);
char *ldns_tsig_keydata(ldns_tsig_credentials *);
char *ldns_tsig_keyname_clone(ldns_tsig_credentials *);
char *ldns_tsig_keydata_clone(ldns_tsig_credentials *);

/**
 * verifies the tsig rr for the given packet and key (string?).
 * The wire must be given too because tsig does not sign normalized packets.
 *
 * \return true if tsig is correct, false if not, or if tsig is not set
 */
bool ldns_pkt_tsig_verify(ldns_pkt *pkt, uint8_t *wire, size_t wire_size,
    const char *key_name, const char *key_data, ldns_rdf *mac);

/**
 * creates a tsig rr for the given packet and key (string?).
 * \param[in] pkt the packet to sign
 * \param[in] key_name the name of the shared key
 * \param[in] key_data the key in base 64 format
 * \param[in] fudge seconds of error permitted in time signed
 * \param[in] algorithm_name the name of the algorithm used (TODO more than only hmac-md5.sig-alg.reg.int.?)
 * \param[in] query_mac is added to the digest if not NULL (so NULL is for signing queries, not NULL is for signing answers)
 * \return status (OK if success)
 */
ldns_status ldns_pkt_tsig_sign(ldns_pkt *pkt, const char *key_name,
    const char *key_data, uint16_t fudge, const char *algorithm_name,
    ldns_rdf *query_mac);

#endif /* _LDNS_TSIG_H_ */
